@@ -1,6 +1,6 @@
 // main.cpp
 
-// Copyright (C) 2011-2018 by Werner Lemberg.
+// Copyright (C) 2011-2019 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -232,7 +232,7 @@ err(TA_Error error,
     {
       fprintf(stderr, "%s:", data->control_name);
       if (errlinenum)
-        fprintf(stderr, "%d:", errlinenum);
+        fprintf(stderr, "%u:", errlinenum);
       if (errpos && errline)
         fprintf(stderr, "%d:", int(errpos - errline + 1));
       if (error_string)
@@ -528,7 +528,7 @@ show_help(bool
 "\n"
 "Report bugs to: freetype-devel@nongnu.org\n"
 "\n"
-"ttfautohint home page: <http://www.freetype.org/ttfautohint>\n");
+"ttfautohint home page: <https://www.freetype.org/ttfautohint>\n");
 
   if (is_error)
     exit(EXIT_FAILURE);
@@ -546,7 +546,7 @@ show_version()
 #else
 "ttfautohint " VERSION "\n"
 #endif
-"Copyright (C) 2011-2018 Werner Lemberg <wl@gnu.org>.\n"
+"Copyright (C) 2011-2019 Werner Lemberg <wl@gnu.org>.\n"
 "License: FreeType License (FTL) or GNU GPLv2.\n"
 "This is free software: you are free to change and redistribute it.\n"
 "There is NO WARRANTY, to the extent permitted by law.\n");
