@@ -1,6 +1,6 @@
 // maingui.cpp
 
-// Copyright (C) 2012-2018 by Werner Lemberg.
+// Copyright (C) 2012-2019 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -233,16 +233,16 @@ Main_GUI::about()
   QMessageBox::about(this,
                      tr("About TTFautohint"),
                      tr("<p>This is <b>TTFautohint</b> version %1<br>"
-                        " Copyright %2 2011-2018<br>"
+                        " Copyright %2 2011-2019<br>"
                         " by Werner Lemberg <tt>&lt;wl@gnu.org&gt;</tt></p>"
                         ""
                         "<p><b>TTFautohint</b> adds new auto-generated hints"
                         " to a TrueType font or TrueType collection.</p>"
                         ""
                         "<p>License:"
-                        " <a href='http://git.savannah.gnu.org/cgit/freetype/freetype2.git/tree/docs/FTL.TXT'>FreeType"
+                        " <a href='https://git.savannah.gnu.org/cgit/freetype/freetype2.git/tree/docs/FTL.TXT'>FreeType"
                         " License (FTL)</a> or"
-                        " <a href='http://git.savannah.gnu.org/cgit/freetype/freetype2.git/tree/docs/GPLv2.TXT'>GNU"
+                        " <a href='https://git.savannah.gnu.org/cgit/freetype/freetype2.git/tree/docs/GPLv2.TXT'>GNU"
                         " GPLv2</a></p>")
                         .arg(VERSION)
                         .arg(QChar(0xA9)));
