@@ -5,7 +5,7 @@
 #
 # Process a blue zone character data file.
 #
-# Copyright 2013 by
+# Copyright 2013-2019 by
 # David Turner, Robert Wilhelm, and Werner Lemberg.
 #
 # This file is part of the FreeType project, and may only be used,
@@ -17,7 +17,7 @@
 use strict;
 use warnings;
 use English '-no_match_vars';
-use open ':std', ':locale';
+use open ':std', ':encoding(UTF-8)';
 
 
 my $prog = $PROGRAM_NAME;
@@ -38,7 +38,8 @@ my $curr_max;          # Name of the current maximum value.
 
 my $curr_enum_element; # Name of the current enumeration element.
 my $curr_offset;       # The offset relative to current aux. variable.
-my $curr_elem_size;    # The size of the current string or block.
+my $curr_elem_size;    # The number of non-space characters in the current string or
+                       # the number of elements in the current block.
 
 my $have_sections = 0; # Boolean; set if start of a section has been seen.
 my $have_strings;      # Boolean; set if current section contains strings.
@@ -63,15 +64,15 @@ my $enum_element_re = qr/ ^ \s* ( [A-Za-z0-9_]+ ) \s* $ /x;
 # '#' <preprocessor directive> '\n'
 my $preprocessor_re = qr/ ^ \# /x;
 
-# '/' '/' <comment> '\n'
-my $comment_re = qr| ^ // |x;
+# [<ws>] '/' '/' <comment> '\n'
+my $comment_re = qr| ^ \s* // |x;
 
 # empty line
 my $whitespace_only_re = qr/ ^ \s* $ /x;
 
 # [<ws>] '"' <string> '"' [<ws>] '\n'  (<string> doesn't contain newlines)
 my $string_re = qr/ ^ \s*
-                       " ( (?: [^"\\]++ | \\. )*+ ) "
+                       " ( (?> (?: (?> [^"\\]+ ) | \\. )* ) ) "
                        \s* $ /x;
 
 # [<ws>] '{' <block> '}' [<ws>] '\n'  (<block> can contain newlines)
@@ -159,9 +160,14 @@ sub convert_ascii_chars
   # A series of ASCII characters in the printable range.
   my $s = shift;
 
-  my $count = $s =~ s/\G(.)/'$1', /g;
-  $curr_offset += $count;
-  $curr_elem_size += $count;
+  # We reduce multiple space characters to a single one.
+  $s =~ s/ +/ /g;
+
+  # Count all non-space characters.  Note that `()' applies a list context
+  # to the capture that is used to count the elements.
+  $curr_elem_size += () = $s =~ /[^ ]/g;
+
+  $curr_offset += $s =~ s/\G(.)/'$1', /g;
 
   return $s;
 }
@@ -194,7 +200,7 @@ sub convert_literal
 
 sub aux_name
 {
-  return "af_blue_" . $num_sections. "_" . join('_', reverse @name_stack);
+  return "af_blue_" . $num_sections. "_" . join('_', @name_stack);
 }
 
 
@@ -210,7 +216,7 @@ sub aux_name_next
 
 sub enum_val_string
 {
-  # Build string which holds code to save the current offset in an
+  # Build string that holds code to save the current offset in an
   # enumeration element.
   my $aux = shift;
 
@@ -288,7 +294,7 @@ while (<DATA>)
     {
       # Having preprocessor conditionals complicates the computation of
       # correct offset values.  We have to introduce auxiliary enumeration
-      # elements with the name `af_blue_<s>_<n1>_<n2>_...' which store
+      # elements with the name `af_blue_<s>_<n1>_<n2>_...' that store
       # offsets to be used in conditional clauses.  `<s>' is the number of
       # sections seen so far, `<n1>' is the number of `#if' and `#endif'
       # conditionals seen so far in the topmost level, `<n2>' the number of
@@ -344,24 +350,27 @@ while (<DATA>)
 
         $curr_offset = 0;
       }
-      elsif (/ ^ \# \s* endif /x)
+      elsif (/ ^ (\# \s*) endif /x)
       {
         my $prev_else = pop @else_stack;
         Die("unbalanced #endif") unless defined($prev_else);
 
         pop @name_stack;
-        $name_stack[$#name_stack]++;
 
         # If there is no else-clause for an if-clause, we add one.  This is
         # necessary to have correct offsets.
         if (!$prev_else)
         {
-          push @{$diversions{$curr_enum}}, enum_val_string(aux_name())
-                                           . "#else\n";
+          # Use amount of whitespace from `endif'.
+          push @{$diversions{$curr_enum}}, enum_val_string(aux_name_next())
+                                           . $1 . "else\n";
+          $last_aux = aux_name();
 
           $curr_offset = 0;
         }
 
+        $name_stack[$#name_stack]++;
+
         push @{$diversions{$curr_enum}}, enum_val_string(aux_name());
         $last_aux = aux_name();
 
