@@ -1,7 +1,7 @@
 /* tabytecode.c */
 
 /*
- * Copyright (C) 2011-2018 by Werner Lemberg.
+ * Copyright (C) 2011-2019 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -901,8 +901,7 @@ TA_sfnt_build_delta_exceptions(SFNT* sfnt,
   }
 
   /* merge `before IUP' delta stacks into a single one */
-  if (need_before_IUP_words
-      || (!need_before_IUP_words && !need_before_IUP_word_counts))
+  if (need_before_IUP_words || !need_before_IUP_word_counts)
   {
     FT_UInt num_args = 0;
 
@@ -1002,8 +1001,7 @@ TA_sfnt_build_delta_exceptions(SFNT* sfnt,
     BCI(IUP_y);
 
   /* merge `after IUP' delta stacks into a single one */
-  if (need_after_IUP_words
-      || (!need_after_IUP_words && !need_after_IUP_word_counts))
+  if (need_after_IUP_words || !need_after_IUP_word_counts)
   {
     FT_UInt num_args = 0;
 
