@@ -1,7 +1,7 @@
 /* tahints.h */
 
 /*
- * Copyright (C) 2011-2018 by Werner Lemberg.
+ * Copyright (C) 2011-2019 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -60,7 +60,7 @@ typedef enum TA_Direction_
  *
  *  by David Turner and Werner Lemberg
  *
- *    http://www.tug.org/TUGboat/Articles/tb24-3/lemberg.pdf
+ *    https://www.tug.org/TUGboat/Articles/tb24-3/lemberg.pdf
  *
  *  with appropriate updates.
  *
@@ -249,6 +249,12 @@ typedef struct TA_PointRec_
 
   TA_Point next; /* next point in contour */
   TA_Point prev; /* previous point in contour */
+
+#ifdef TA_DEBUG
+  /* track `before' and `after' edges for strong points */
+  TA_Edge before[2];
+  TA_Edge after[2];
+#endif
 } TA_PointRec;
 
 
