@@ -1,7 +1,7 @@
 /* tastyles.h */
 
 /*
- * Copyright (C) 2014-2018 by Werner Lemberg.
+ * Copyright (C) 2014-2019 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -326,6 +326,13 @@ STYLE(mlym_dflt, MLYM_DFLT,
       TA_BLUE_STRINGSET_MLYM,
       TA_COVERAGE_DEFAULT)
 
+STYLE(mong_dflt, MONG_DFLT,
+      "Mongolian default style",
+      TA_WRITING_SYSTEM_LATIN,
+      TA_SCRIPT_MONG,
+      TA_BLUE_STRINGSET_MONG,
+      TA_COVERAGE_DEFAULT)
+
 STYLE(mymr_dflt, MYMR_DFLT,
       "Myanmar default style",
       TA_WRITING_SYSTEM_LATIN,
